#ifndef __PS_FONTENC_H__
#define __PS_FONTENC_H__

extern ENCODING fontencoding[];

#endif
